@@ -1,9 +1,6 @@
-use std::{
-    path::{Path, PathBuf},
-    time::Duration,
-};
+use std::path::{Path, PathBuf};
 
-use rusqlite::{params, Connection, Result};
+use rusqlite::{params, Connection, Result, Statement};
 
 lazy_static! {
     static ref DB_DIR: PathBuf = {
@@ -24,10 +21,9 @@ impl Database {
     pub fn new() -> Self {
         let conn = Connection::open(DB_DIR.as_path()).unwrap();
 
-        conn.busy_timeout(Duration::from_millis(0)).unwrap();
         conn.pragma_update(None, "journal_mode", "WAL").unwrap();
         conn.pragma_update(None, "synchronous", "0").unwrap();
-        conn.pragma_update(None, "temp_store", "MEMORY").unwrap();
+        conn.pragma_update(None, "temp_store", "0").unwrap();
 
         conn.execute(
             "CREATE TABLE IF NOT EXISTS tasks(
@@ -49,6 +45,7 @@ impl Database {
             [],
         )
         .unwrap();
+
         Self { conn }
     }
     pub fn insert_task(&self, task: &str, board: Option<String>) {
@@ -81,7 +78,6 @@ impl Database {
     }
     pub fn delete_tasks(&self, ids: &[usize]) {
         let ids = self.get_real_ids(ids);
-
         for id in ids {
             self.conn
                 .execute("DELETE FROM tasks WHERE rowid = ?", [id])
@@ -104,29 +100,6 @@ impl Database {
             .execute("DELETE FROM tasks WHERE checked = '1'", [])?;
         Ok(())
     }
-    pub fn total_checked(&self) -> usize {
-        let mut stmt = self
-            .conn
-            .prepare("SELECT COUNT(*) FROM tasks WHERE checked = '1'")
-            .unwrap();
-        let mut rows = stmt.query([]).unwrap();
-
-        if let Some(row) = rows.next().unwrap() {
-            return row.get(0).unwrap();
-        } else {
-            0
-        }
-    }
-    pub fn total_tasks(&self) -> usize {
-        let mut stmt = self.conn.prepare("SELECT COUNT(*) FROM tasks").unwrap();
-        let mut rows = stmt.query([]).unwrap();
-
-        if let Some(row) = rows.next().unwrap() {
-            return row.get(0).unwrap();
-        } else {
-            0
-        }
-    }
     pub fn get_real_ids(&self, ids: &[usize]) -> Vec<usize> {
         let boards = self.get_boards();
         let mut real_ids = Vec::new();
@@ -141,26 +114,17 @@ impl Database {
             .collect()
     }
     pub fn get_boards(&self) -> Vec<Board> {
-        let mut stmt = self
-            .conn
-            .prepare("SELECT DISTINCT board FROM tasks")
-            .unwrap();
-        let boards: Vec<String> = stmt
-            .query_map([], |row| Ok(row.get(0).unwrap()))
-            .unwrap()
-            .flatten()
-            .collect();
+        let mut stmt = self.stmt("SELECT DISTINCT board FROM tasks");
+        let rows = stmt.query_map([], |row| row.get(0)).unwrap();
+        let boards: Vec<String> = rows.into_iter().flatten().collect();
 
         boards
             .iter()
             .map(|board| {
-                let mut stmt = self
-                    .conn
-                    .prepare(&format!(
-                        "SELECT *, rowid FROM tasks WHERE board = '{}'",
-                        board
-                    ))
-                    .unwrap();
+                let mut stmt = self.stmt(&format!(
+                    "SELECT *, rowid FROM tasks WHERE BOARD = '{}'",
+                    board
+                ));
 
                 let mut total_checked: usize = 0;
 
@@ -192,6 +156,28 @@ impl Database {
             })
             .collect()
     }
+    pub fn total_checked(&self) -> usize {
+        self.total("SELECT COUNT(*) FROM tasks WHERE checked = '1'")
+    }
+    pub fn total_tasks(&self) -> usize {
+        self.total("SELECT COUNT(*) FROM tasks")
+    }
+    pub fn total_notes(&self) -> usize {
+        self.total("SELECT COUNT(*) FROM tasks WHERE note = '1'")
+    }
+    pub fn total(&self, query: &str) -> usize {
+        let mut stmt = self.stmt(query);
+        let mut rows = stmt.query([]).unwrap();
+
+        if let Some(row) = rows.next().unwrap() {
+            row.get(0).unwrap()
+        } else {
+            0
+        }
+    }
+    fn stmt(&self, query: &str) -> Statement {
+        self.conn.prepare(query).unwrap()
+    }
 }
 
 pub struct Task {
